@@ -146,7 +146,7 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        params=self._create_params(id=user_id,toggle=toggle,insert=insert,delete=delete)
+        params=self._create_params(user_id=user_id,toggle=toggle,insert=insert,delete=delete)
         headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None,'Authorization':f'Bearer {token if token else self.token}'})
         return await self._make_request(f"{APIBaseURL}fav/",'get',params=params,headers=headers)
 
