@@ -25,17 +25,15 @@ class WaifuException(Exception):
 
 class APIException(WaifuException):
     """Exception due to an error response from waifu.im API."""
-    def __init__(self, status: int, reason: str, errormessage: str) -> None:
+    def __init__(self, status: int,message: str) -> None:
         """Initializes the APIException.
         Args:
             status: HTTP status code of the response.
-            reason: HTTP status reason of the response.
             message: The response message.
         """
-        super().__init__(f'{status} {reason}: {errormessage}')
+        super().__init__(f'{status}: {message}')
         self.status=status
-        self.reason=reason
-        self.errormessage=errormessage
+        self.message=message
         
 
 class NoToken(WaifuException):
